Author: uqs
Date: Fri Dec 30 11:02:40 2011
New Revision: 228992
URL: http://svn.freebsd.org/changeset/base/228992

Log:
  Spelling fixes for usr.bin/

Modified:
  head/usr.bin/csup/fixups.c
  head/usr.bin/csup/mux.c
  head/usr.bin/csup/rcsfile.c
  head/usr.bin/finger/finger.c
  head/usr.bin/fstat/fstat.c
  head/usr.bin/indent/indent.c
  head/usr.bin/indent/io.c
  head/usr.bin/ipcs/ipc.c
  head/usr.bin/ipcs/ipc.h
  head/usr.bin/lex/NEWS
  head/usr.bin/lex/flexdef.h
  head/usr.bin/lex/tblcmp.c
  head/usr.bin/limits/limits.c
  head/usr.bin/locate/locate/locate.c
  head/usr.bin/locate/locate/util.c
  head/usr.bin/login/login_fbtab.c
  head/usr.bin/mail/head.c
  head/usr.bin/mail/main.c
  head/usr.bin/mail/util.c
  head/usr.bin/make/GNode.h
  head/usr.bin/make/arch.c
  head/usr.bin/make/buf.c
  head/usr.bin/make/for.c
  head/usr.bin/make/job.c
  head/usr.bin/make/main.c
  head/usr.bin/make/str.c
  head/usr.bin/make/var.c
  head/usr.bin/man/man.sh
  head/usr.bin/ncplogin/ncplogin.c
  head/usr.bin/netstat/ipx.c
  head/usr.bin/pr/pr.c
  head/usr.bin/rpcgen/rpc_svcout.c
  head/usr.bin/rpcinfo/rpcinfo.c
  head/usr.bin/systat/icmp6.c
  head/usr.bin/talk/ctl_transact.c
  head/usr.bin/talk/invite.c
  head/usr.bin/tip/tip/tip.h
  head/usr.bin/top/machine.c
  head/usr.bin/vgrind/extern.h
  head/usr.bin/vgrind/vfontedpr.c
  head/usr.bin/xlint/lint1/decl.c
  head/usr.bin/xlint/lint1/emit1.c
  head/usr.bin/xlint/lint1/func.c
  head/usr.bin/xlint/lint1/mem1.c
  head/usr.bin/xlint/lint2/chk.c
  head/usr.bin/xlint/lint2/read.c
  head/usr.bin/xlint/xlint/xlint.c
  head/usr.bin/yacc/NEW_FEATURES
  head/usr.bin/yacc/reader.c

Modified: head/usr.bin/csup/fixups.c
==============================================================================
--- head/usr.bin/csup/fixups.c  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/csup/fixups.c  Fri Dec 30 11:02:40 2011        (r228992)
@@ -38,7 +38,7 @@
 /*
  * A synchronized queue to implement fixups.  The updater thread adds
  * fixup requests to the queue with fixups_put() when a checksum
- * mismatch error occured.  It then calls fixups_close() when he's
+ * mismatch error occurred.  It then calls fixups_close() when he's
  * done requesting fixups.  The detailer thread gets the fixups with
  * fixups_get() and then send the requests to the server.
  *

Modified: head/usr.bin/csup/mux.c
==============================================================================
--- head/usr.bin/csup/mux.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/csup/mux.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -680,7 +680,7 @@ mux_init(struct mux *m)
 
 /*
  * Close all the channels, terminate the sender and receiver thread.
- * This is an important function because it is used everytime we need
+ * This is an important function because it is used every time we need
  * to wake up all the worker threads to abort the program.
  *
  * This function accepts an error message that will be printed if the

Modified: head/usr.bin/csup/rcsfile.c
==============================================================================
--- head/usr.bin/csup/rcsfile.c Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/csup/rcsfile.c Fri Dec 30 11:02:40 2011        (r228992)
@@ -1254,8 +1254,8 @@ rcsfile_insertsorteddelta(struct rcsfile
 /*
  * Insert a delta into the correct place in branch. A trunk branch will have
  * different ordering scheme and be sorted by revision number, but a normal
- * branch will be sorted by date to maintain compability with branches that is
- * "hand-hacked".
+ * branch will be sorted by date to maintain compatibility with branches that
+ * is "hand-hacked".
  */
 static void
 rcsfile_insertdelta(struct branch *b, struct delta *d, int trunk)

Modified: head/usr.bin/finger/finger.c
==============================================================================
--- head/usr.bin/finger/finger.c        Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/finger/finger.c        Fri Dec 30 11:02:40 2011        
(r228992)
@@ -299,8 +299,8 @@ userlist(int argc, char **argv)
                goto net;
 
        /*
-        * Mark any arguments beginning with '/' as invalid so that we 
-        * don't accidently confuse them with expansions from finger.conf
+        * Mark any arguments beginning with '/' as invalid so that we
+        * don't accidentally confuse them with expansions from finger.conf
         */
        for (p = argv, ip = used; *p; ++p, ++ip)
            if (**p == '/') {

Modified: head/usr.bin/fstat/fstat.c
==============================================================================
--- head/usr.bin/fstat/fstat.c  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/fstat/fstat.c  Fri Dec 30 11:02:40 2011        (r228992)
@@ -150,7 +150,7 @@ do_fstat(int argc, char **argv)
                        if (getfname(*argv))
                                checkfile = 1;
                }
-               if (!checkfile) /* file(s) specified, but none accessable */
+               if (!checkfile) /* file(s) specified, but none accessible */
                        exit(1);
        }
 

Modified: head/usr.bin/indent/indent.c
==============================================================================
--- head/usr.bin/indent/indent.c        Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/indent/indent.c        Fri Dec 30 11:02:40 2011        
(r228992)
@@ -326,7 +326,7 @@ main(int argc, char **argv)
 
            case lbrace:        /* this is a brace that starts the compound
                                 * stmt */
-               if (sc_end == 0) {      /* ignore buffering if a comment wasnt
+               if (sc_end == 0) {      /* ignore buffering if a comment wasn't
                                         * stored up */
                    ps.search_brace = false;
                    goto check_type;
@@ -384,7 +384,7 @@ main(int argc, char **argv)
                        && e_code != s_code && e_code[-1] == '}'))
                    force_nl = false;
 
-               if (sc_end == 0) {      /* ignore buffering if comment wasnt
+               if (sc_end == 0) {      /* ignore buffering if comment wasn't
                                         * saved up */
                    ps.search_brace = false;
                    goto check_type;
@@ -794,8 +794,8 @@ check_type:
                /* ?            dec_ind = 0; */
            }
            else {
-               ps.decl_on_line = false;        /* we cant be in the middle of
-                                                * a declaration, so dont do
+               ps.decl_on_line = false;        /* we can't be in the middle of
+                                                * a declaration, so don't do
                                                 * special indentation of
                                                 * comments */
                if (blanklines_after_declarations_at_proctop

Modified: head/usr.bin/indent/io.c
==============================================================================
--- head/usr.bin/indent/io.c    Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/indent/io.c    Fri Dec 30 11:02:40 2011        (r228992)
@@ -232,7 +232,7 @@ dump_line(void)
                        target = ((target - 1) & ~7) + 9, com_st++;
                    else
                        target = 1;
-               if (cur_col > target) { /* if comment cant fit on this line,
+               if (cur_col > target) { /* if comment can't fit on this line,
                                         * put it on next line */
                    putc('\n', output);
                    cur_col = 1;

Modified: head/usr.bin/ipcs/ipc.c
==============================================================================
--- head/usr.bin/ipcs/ipc.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/ipcs/ipc.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -24,7 +24,7 @@
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * The split of ipcs.c into ipcs.c and ipc.c to accomodate the
+ * The split of ipcs.c into ipcs.c and ipc.c to accommodate the
  * changes in ipcrm.c was done by Edwin Groothuis <ed...@freebsd.org>
  */
 

Modified: head/usr.bin/ipcs/ipc.h
==============================================================================
--- head/usr.bin/ipcs/ipc.h     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/ipcs/ipc.h     Fri Dec 30 11:02:40 2011        (r228992)
@@ -24,7 +24,7 @@
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
  * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * The split of ipcs.c into ipcs.c and ipc.c to accomodate the
+ * The split of ipcs.c into ipcs.c and ipc.c to accommodate the
  * changes in ipcrm.c was done by Edwin Groothuis <ed...@freebsd.org>
  *
  * $FreeBSD$

Modified: head/usr.bin/lex/NEWS
==============================================================================
--- head/usr.bin/lex/NEWS       Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/lex/NEWS       Fri Dec 30 11:02:40 2011        (r228992)
@@ -1,3 +1,5 @@
+$FreeBSD$
+
 Changes between release 2.5.4 (11Sep96) and release 2.5.3:
 
        - Fixed a bug introduced in 2.5.3 that blew it when a call
@@ -944,7 +946,7 @@ Changes between 2.3 (full) release of 28
          given.  To specify an end-of-file action for just the initial
          state, use <INITIAL><<EOF>>.
 
-       - -d debug output is now contigent on the global yy_flex_debug
+       - -d debug output is now contingent on the global yy_flex_debug
          being set to a non-zero value, which it is by default.
 
        - A new macro, YY_USER_INIT, is provided for the user to specify
@@ -987,7 +989,7 @@ Changes between 2.3 (full) release of 28
        - yy_switch_to_buffer() can be used in the yywrap() macro/routine.
 
        - flex scanners do not use stdio for their input, and hence when
-         writing an interactive scanner one must explictly call fflush()
+         writing an interactive scanner one must explicitly call fflush()
          after writing out a prompt.
 
        - flex scanner can be made reentrant (after a fashion) by using

Modified: head/usr.bin/lex/flexdef.h
==============================================================================
--- head/usr.bin/lex/flexdef.h  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/lex/flexdef.h  Fri Dec 30 11:02:40 2011        (r228992)
@@ -869,7 +869,7 @@ extern void mark_defs1 PROTO((void));
 /* Mark the current position in the action array as the end of the prolog. */
 extern void mark_prolog PROTO((void));
 
-/* Generate a data statment for a two-dimensional array. */
+/* Generate a data statement for a two-dimensional array. */
 extern void mk2data PROTO((int));
 
 extern void mkdata PROTO((int));       /* generate a data statement */

Modified: head/usr.bin/lex/tblcmp.c
==============================================================================
--- head/usr.bin/lex/tblcmp.c   Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/lex/tblcmp.c   Fri Dec 30 11:02:40 2011        (r228992)
@@ -510,7 +510,7 @@ void mkdeftbl()
  * (i.e., jam entries) into the table.  It is assumed that by linking to
  * "JAMSTATE" they will be taken care of.  In any case, entries in "state"
  * marking transitions to "SAME_TRANS" are treated as though they will be
- * taken care of by whereever "deflink" points.  "totaltrans" is the total
+ * taken care of by wherever "deflink" points.  "totaltrans" is the total
  * number of transitions out of the state.  If it is below a certain threshold,
  * the tables are searched for an interior spot that will accommodate the
  * state array.

Modified: head/usr.bin/limits/limits.c
==============================================================================
--- head/usr.bin/limits/limits.c        Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/limits/limits.c        Fri Dec 30 11:02:40 2011        
(r228992)
@@ -236,7 +236,7 @@ static struct {
 
 /*
  * One letter for each resource levels.
- * NOTE: There is a dependancy on the corresponding
+ * NOTE: There is a dependency on the corresponding
  * letter index being equal to the resource number.
  * If sys/resource.h defines are changed, this needs
  * to be modified accordingly!

Modified: head/usr.bin/locate/locate/locate.c
==============================================================================
--- head/usr.bin/locate/locate/locate.c Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/locate/locate/locate.c Fri Dec 30 11:02:40 2011        
(r228992)
@@ -188,7 +188,7 @@ main(argc, argv)
 
         /* no (valid) database as argument */
         if (dbv == NULL || *dbv == NULL) {
-                /* try to read database from enviroment */
+                /* try to read database from environment */
                 if ((path_fcodes = getenv("LOCATE_PATH")) == NULL ||
                     *path_fcodes == '\0')
                         /* use default database */

Modified: head/usr.bin/locate/locate/util.c
==============================================================================
--- head/usr.bin/locate/locate/util.c   Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/locate/locate/util.c   Fri Dec 30 11:02:40 2011        
(r228992)
@@ -218,11 +218,11 @@ tolower_word(word)
 
 
 /*
- * Read integer from mmap pointer. 
- * Essential a simple  ``return *(int *)p'' but avoid sigbus 
+ * Read integer from mmap pointer.
+ * Essential a simple  ``return *(int *)p'' but avoid sigbus
  * for integer alignment (SunOS 4.x, 5.x).
  *
- * Convert network byte order to host byte order if neccessary. 
+ * Convert network byte order to host byte order if necessary.
  * So we can read on FreeBSD/i386 (little endian) a locate database
  * which was built on SunOS/sparc (big endian).
  */
@@ -254,7 +254,7 @@ getwm(p)
 /*
  * Read integer from stream.
  *
- * Convert network byte order to host byte order if neccessary. 
+ * Convert network byte order to host byte order if necessary.
  * So we can read on FreeBSD/i386 (little endian) a locate database
  * which was built on SunOS/sparc (big endian).
  */

Modified: head/usr.bin/login/login_fbtab.c
==============================================================================
--- head/usr.bin/login/login_fbtab.c    Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/login/login_fbtab.c    Fri Dec 30 11:02:40 2011        
(r228992)
@@ -25,7 +25,7 @@
        SunOS 4.1.x fbtab(5) and SunOS 5.x logindevperm(4) manual
        pages. The program first looks for /etc/fbtab. If that file
        cannot be opened it attempts to process /etc/logindevperm.
-       We expect entries with the folowing format:
+       We expect entries with the following format:
 
            Comments start with a # and extend to the end of the line.
 

Modified: head/usr.bin/mail/head.c
==============================================================================
--- head/usr.bin/mail/head.c    Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/mail/head.c    Fri Dec 30 11:02:40 2011        (r228992)
@@ -47,7 +47,7 @@ __FBSDID("$FreeBSD$");
 /*
  * See if the passed line buffer is a mail header.
  * Return true if yes.  Note the extreme pains to
- * accomodate all funny formats.
+ * accommodate all funny formats.
  */
 int
 ishead(char linebuf[])

Modified: head/usr.bin/mail/main.c
==============================================================================
--- head/usr.bin/mail/main.c    Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/mail/main.c    Fri Dec 30 11:02:40 2011        (r228992)
@@ -259,7 +259,7 @@ Usage: %s [-dEiInv] [-s subject] [-c cc-
                if (ef == NULL)
                        ef = "%";
                if (setfile(ef) <= 0)
-                       /* Either an error has occured, or no mail */
+                       /* Either an error has occurted, or no mail */
                        exit(1);
                else
                        exit(0);

Modified: head/usr.bin/mail/util.c
==============================================================================
--- head/usr.bin/mail/util.c    Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/mail/util.c    Fri Dec 30 11:02:40 2011        (r228992)
@@ -550,7 +550,7 @@ newname:
 }
 
 /*
- * Count the occurances of c in str
+ * Count the occurrances of c in str
  */
 int
 charcount(char *str, int c)

Modified: head/usr.bin/make/GNode.h
==============================================================================
--- head/usr.bin/make/GNode.h   Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/GNode.h   Fri Dec 30 11:02:40 2011        (r228992)
@@ -139,7 +139,7 @@ typedef struct GNode {
                UPTODATE,       /* Was already up-to-date */
 
                /*
-                * An error occured while it was being
+                * An error occurred while it was being
                 * made (used only in compat mode)
                 */
                ERROR,

Modified: head/usr.bin/make/arch.c
==============================================================================
--- head/usr.bin/make/arch.c    Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/arch.c    Fri Dec 30 11:02:40 2011        (r228992)
@@ -179,8 +179,8 @@ Boolean arch_fatal = TRUE;
 
 /**
  * ArchError
- *     An error happend while handling an archive. BSDmake traditionally
- *     ignored these errors. Now this is dependend on the global arch_fatal
+ *     An error happened while handling an archive. BSDmake traditionally
+ *     ignored these errors. Now this is dependent on the global arch_fatal
  *     which, if true, makes these errors fatal and, if false, just emits an
  *     error message.
  */
@@ -529,7 +529,7 @@ ArchArchiveOpen(const char *archive, con
 
 /*
  * Read the next header from the archive. The return value will be +1 if
- * the header is read successfully, 0 on EOF and -1 if an error happend.
+ * the header is read successfully, 0 on EOF and -1 if an error happened.
  * On a successful return sname contains the truncated member name and
  * member the full name. hdr contains the member header. For the symbol table
  * names of length 0 are returned. The entry for the file name table is never
@@ -830,7 +830,7 @@ ArchFindMember(const char *archive, cons
                 * (3) the name is longer and the archive doesn't support long
                 * names.
                 * Because we don't know whether the archive supports long
-                * names or not we need to be carefull.
+                * names or not we need to be careful.
                 */
                if (member == NULL) {
                        /* special case - symbol table */
@@ -942,7 +942,7 @@ ArchStatMember(const char *archive, cons
                ArchArchiveClose(arf);
 
                if (t < 0) {
-                       /* error happend - throw away everything */
+                       /* error happened - throw away everything */
                        Hash_DeleteTable(&ar->members);
                        free(ar->name);
                        free(ar);

Modified: head/usr.bin/make/buf.c
==============================================================================
--- head/usr.bin/make/buf.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/buf.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -206,7 +206,7 @@ Buf_Destroy(Buffer *buf, Boolean freeDat
 
 /**
  * Replace the last byte in a buffer.  If the buffer was empty
- * intially, then a new byte will be added.
+ * initially, then a new byte will be added.
  */
 void
 Buf_ReplaceLastByte(Buffer *bp, Byte byte)

Modified: head/usr.bin/make/for.c
==============================================================================
--- head/usr.bin/make/for.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/for.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -218,7 +218,7 @@ For_Eval(char *line)
 /*-
  *-----------------------------------------------------------------------
  * For_Run --
- *     Run the for loop, immitating the actions of an include file
+ *     Run the for loop, imitating the actions of an include file
  *
  * Results:
  *     None.

Modified: head/usr.bin/make/job.c
==============================================================================
--- head/usr.bin/make/job.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/job.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -1897,7 +1897,7 @@ JobOutput(Job *job, char *cp, char *endp
  *     this makes up a line, we print it tagged by the job's identifier,
  *     as necessary.
  *     If output has been collected in a temporary file, we open the
- *     file and read it line by line, transfering it to our own
+ *     file and read it line by line, transferring it to our own
  *     output channel until the file is empty. At which point we
  *     remove the temporary file.
  *     In both cases, however, we keep our figurative eye out for the

Modified: head/usr.bin/make/main.c
==============================================================================
--- head/usr.bin/make/main.c    Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/main.c    Fri Dec 30 11:02:40 2011        (r228992)
@@ -267,13 +267,13 @@ ReadMakefile(const char p[])
                         * XXX The realpath stuff breaks relative includes
                         * XXX in some cases.   The problem likely is in
                         * XXX parse.c where it does special things in
-                        * XXX ParseDoInclude if the file is relateive
+                        * XXX ParseDoInclude if the file is relative
                         * XXX or absolute and not a system file.  There
                         * XXX it assumes that if the current file that's
                         * XXX being included is absolute, that any files
                         * XXX that it includes shouldn't do the -I path
-                        * XXX stuff, which is inconsistant with historical
-                        * XXX behavior.  However, I can't pentrate the mists
+                        * XXX stuff, which is inconsistent with historical
+                        * XXX behavior.  However, I can't penetrate the mists
                         * XXX further, so I'm putting this workaround in
                         * XXX here until such time as the underlying bug
                         * XXX can be fixed.
@@ -675,7 +675,7 @@ chdir_verify_path(const char *path, char
  * prevent a forkbomb from happening, in a dumb and mechanical way.
  *
  * Side Effects:
- *     Creates or modifies enviornment variable MKLVL_ENVVAR via setenv().
+ *     Creates or modifies environment variable MKLVL_ENVVAR via setenv().
  */
 static void
 check_make_level(void)
@@ -954,7 +954,7 @@ main(int argc, char **argv)
        }
 
        /*
-        * Set machine_cpu to the minumum supported CPU revision based
+        * Set machine_cpu to the minimum supported CPU revision based
         * on the target architecture, if not already set.
         */
        if ((machine_cpu = getenv("MACHINE_CPU")) == NULL) {
@@ -1047,7 +1047,7 @@ main(int argc, char **argv)
         *
         * Once things are initted,
         * have to add the original directory to the search path,
-        * and modify the paths for the Makefiles apropriately.  The
+        * and modify the paths for the Makefiles appropriately.  The
         * current directory is also placed as a variable for make scripts.
         */
        if (!(pathp = getenv("MAKEOBJDIRPREFIX"))) {

Modified: head/usr.bin/make/str.c
==============================================================================
--- head/usr.bin/make/str.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/str.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -50,10 +50,10 @@ __FBSDID("$FreeBSD$");
 
 /**
  * Initialize the argument array object.  The array is initially
- * eight positions, and will be expaned as neccessary.  The first
+ * eight positions, and will be expanded as necessary.  The first
  * position is set to NULL since everything ignores it.  We allocate
  * (size + 1) since we need space for the terminating NULL.  The
- * buffer is set to NULL, since no common buffer is alloated yet.
+ * buffer is set to NULL, since no common buffer is allocated yet.
  */
 void
 ArgArray_Init(ArgArray *aa)

Modified: head/usr.bin/make/var.c
==============================================================================
--- head/usr.bin/make/var.c     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/make/var.c     Fri Dec 30 11:02:40 2011        (r228992)
@@ -842,7 +842,7 @@ VarLocal(const char name[])
 }
 
 /**
- * Find the given variable in the given context and the enviornment.
+ * Find the given variable in the given context and the environment.
  *
  * Results:
  *     A pointer to the structure describing the desired variable or

Modified: head/usr.bin/man/man.sh
==============================================================================
--- head/usr.bin/man/man.sh     Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/man/man.sh     Fri Dec 30 11:02:40 2011        (r228992)
@@ -369,7 +369,7 @@ man_display_page() {
                while getopts 'egprtv' preproc_arg; do
                        case "${preproc_arg}" in
                        e)      pipeline="$pipeline | $EQN" ;;
-                       g)      ;; # Ignore for compatability.
+                       g)      ;; # Ignore for compatibility.
                        p)      pipeline="$pipeline | $PIC" ;;
                        r)      pipeline="$pipeline | $REFER" ;;
                        t)      pipeline="$pipeline | $TBL" ;;

Modified: head/usr.bin/ncplogin/ncplogin.c
==============================================================================
--- head/usr.bin/ncplogin/ncplogin.c    Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/ncplogin/ncplogin.c    Fri Dec 30 11:02:40 2011        
(r228992)
@@ -188,8 +188,8 @@ main(int argc, char *argv[]) {
                        error = 0;
                } while(0);
                if (error)
-                       errx(EX_DATAERR, 
-                           "an error occured while parsing '%s'",
+                       errx(EX_DATAERR,
+                           "an error occurred while parsing '%s'",
                            argv[argc - 1]);
        }
 

Modified: head/usr.bin/netstat/ipx.c
==============================================================================
--- head/usr.bin/netstat/ipx.c  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/netstat/ipx.c  Fri Dec 30 11:02:40 2011        (r228992)
@@ -201,7 +201,7 @@ spx_stats(u_long off, const char *name, 
        ANYl(spxstat.spxs_sndurg, "packet", " sent with URG only");
        ANYl(spxstat.spxs_sndwinup, "window update-only packet", " sent");
        ANYl(spxstat.spxs_sndctrl, "control (SYN|FIN|RST) packet", " sent");
-       ANYl(spxstat.spxs_sndvoid, "request", " to send a non-existant packet");
+       ANYl(spxstat.spxs_sndvoid, "request", " to send a non-existent packet");
        ANYl(spxstat.spxs_rcvtotal, "total packet", " received");
        ANYl(spxstat.spxs_rcvpack, "packet", " received in sequence");
        ANYl(spxstat.spxs_rcvbyte, "byte", " received in sequence");

Modified: head/usr.bin/pr/pr.c
==============================================================================
--- head/usr.bin/pr/pr.c        Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/pr/pr.c        Fri Dec 30 11:02:40 2011        (r228992)
@@ -822,7 +822,7 @@ mulfile(int argc, char *argv[])
         * do not know how many columns yet. The number of operands provide an
         * upper bound on the number of columns. We use the number of files
         * we can open successfully to set the number of columns. The operation
-        * of the merge operation (-m) in relation to unsuccesful file opens
+        * of the merge operation (-m) in relation to unsuccessful file opens
         * is unspecified by posix.
         */
        j = 0;
@@ -841,7 +841,7 @@ mulfile(int argc, char *argv[])
                return(1);
 
        /*
-        * calculate page boundries based on open file count
+        * calculate page boundaries based on open file count
         */
        clcnt = j;
        if (nmwd) {
@@ -987,7 +987,7 @@ mulfile(int argc, char *argv[])
  *     inf:    file
  *     buf:    buffer
  *     lim:    buffer length
- *     cps:    column positon 1st char in buffer (large line support)
+ *     cps:    column position 1st char in buffer (large line support)
  *     trnc:   throw away data more than lim up to \n
  *     mor:    set if more data in line (not truncated)
  */

Modified: head/usr.bin/rpcgen/rpc_svcout.c
==============================================================================
--- head/usr.bin/rpcgen/rpc_svcout.c    Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/rpcgen/rpc_svcout.c    Fri Dec 30 11:02:40 2011        
(r228992)
@@ -325,7 +325,7 @@ write_programs(const char *storage)
 
 /*
  * write out definition of internal function (e.g. _printmsg_1(...))
- *  which calls server's defintion of actual function (e.g. printmsg_1(...)).
+ *  which calls server's definition of actual function (e.g. printmsg_1(...)).
  *  Unpacks single user argument of printmsg_1 to call-by-value format
  *  expected by printmsg_1.
  */

Modified: head/usr.bin/rpcinfo/rpcinfo.c
==============================================================================
--- head/usr.bin/rpcinfo/rpcinfo.c      Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/rpcinfo/rpcinfo.c      Fri Dec 30 11:02:40 2011        
(r228992)
@@ -50,7 +50,7 @@ __FBSDID("$FreeBSD$");
  */
 
 /*
- * We are for now defining PORTMAP here.  It doesnt even compile
+ * We are for now defining PORTMAP here.  It doesn't even compile
  * unless it is defined.
  */
 #ifndef        PORTMAP

Modified: head/usr.bin/systat/icmp6.c
==============================================================================
--- head/usr.bin/systat/icmp6.c Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/systat/icmp6.c Fri Dec 30 11:02:40 2011        (r228992)
@@ -75,7 +75,7 @@ static struct icmp6stat icmp6stat, inits
 12999999999 time-to-live exceeded    999999999 time-to-line exceeded
 13999999999 parameter problem        999999999 parameter problem
 14999999999 neighbor solicitation    999999999 neighbor solicitation
-15999999999 neighbor advertisment    999999999 neighbor advertisment
+15999999999 neighbor advertisement   999999999 neighbor advertisement
 16999999999 router advertisement     999999999 router solicitation
 17
 18
@@ -121,7 +121,7 @@ labelicmp6(void)
        B(12, "time-to-live exceeded");
        B(13, "parameter problem");
        B(14, "neighbor solicitation");
-       B(15, "neighbor advertisment");
+       B(15, "neighbor advertisement");
        L(16, "router advertisement");  R(16, "router solicitation");
 #undef L
 #undef R

Modified: head/usr.bin/talk/ctl_transact.c
==============================================================================
--- head/usr.bin/talk/ctl_transact.c    Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/talk/ctl_transact.c    Fri Dec 30 11:02:40 2011        
(r228992)
@@ -46,7 +46,7 @@ static const char sccsid[] = "@(#)ctl_tr
 
 /*
  * SOCKDGRAM is unreliable, so we must repeat messages if we have
- * not recieved an acknowledgement within a reasonable amount
+ * not received an acknowledgement within a reasonable amount
  * of time
  */
 void

Modified: head/usr.bin/talk/invite.c
==============================================================================
--- head/usr.bin/talk/invite.c  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/talk/invite.c  Fri Dec 30 11:02:40 2011        (r228992)
@@ -87,7 +87,7 @@ invite_remote(void)
        announce_invite();
        /*
         * Shut off the automatic messages for a while,
-        * so we can use the interupt timer to resend the invitation
+        * so we can use the interrupt timer to resend the invitation
         */
        end_msgs();
        setitimer(ITIMER_REAL, &itimer, (struct itimerval *)0);
@@ -117,7 +117,7 @@ invite_remote(void)
 }
 
 /*
- * Routine called on interupt to re-invite the callee
+ * Routine called on interrupt to re-invite the callee
  */
 /* ARGSUSED */
 void

Modified: head/usr.bin/tip/tip/tip.h
==============================================================================
--- head/usr.bin/tip/tip/tip.h  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/tip/tip/tip.h  Fri Dec 30 11:02:40 2011        (r228992)
@@ -99,7 +99,7 @@ typedef
                char    *v_name;        /* whose name is it */
                char    v_type;         /* for interpreting set's */
                char    v_access;       /* protection of touchy ones */
-               char    *v_abrev;       /* possible abreviation */
+               char    *v_abrev;       /* possible abbreviation */
                char    *v_value;       /* casted to a union later */
        }
        value_t;
@@ -162,7 +162,7 @@ typedef
 /*
  * Escape command table definitions --
  *   lookup in this table is performed when ``escapec'' is recognized
- *   at the begining of a line (as defined by the eolmarks variable).
+ *   at the beginning of a line (as defined by the eolmarks variable).
 */
 
 typedef

Modified: head/usr.bin/top/machine.c
==============================================================================
--- head/usr.bin/yacc/reader.c  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/yacc/reader.c  Fri Dec 30 11:02:40 2011        (r228992)
@@ -47,7 +47,7 @@ __FBSDID("$FreeBSD$");
 /*  The line size must be a positive integer.  One hundred was chosen  */
 /*  because few lines in Yacc input grammars exceed 100 characters.    */
 /*  Note that if a line exceeds LINESIZE characters, the line buffer   */
-/*  will be expanded to accomodate it.                                 */
+/*  will be expanded to accommodate it.                                        
*/
 
 #define LINESIZE 100
 
_______________________________________________
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"

Reply via email to
--- head/usr.bin/top/machine.c  Fri Dec 30 10:59:15 2011        (r228991)
+++ head/usr.bin/top/machine.c  Fri Dec 30 11:02:40 2011        (r228992)
@@ -1404,7 +1404,7 @@ compare_ivcsw(void *arg1, void *arg2)
 /*
  * proc_owner(pid) - returns the uid that owns process "pid", or -1 if
  *             the process does not exist.
- *             It is EXTREMLY IMPORTANT that this function work correctly.
+ *             It is EXTREMELY IMPORTANT that this function work correctly.
  *             If top runs setuid root (as in SVR4), then this function
  *             is the only thing that stands in the way of a serious
  *             security problem.  It validates requests for the "kill"

Modified: head/usr.bin/vgrind/extern.h
==============================================================================
--- head/usr.bin/vgrind/extern.h        Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/vgrind/extern.h        Fri Dec 30 11:02:40 2011        
(r228992)
@@ -37,7 +37,7 @@ extern boolean         _escaped;             /*
 extern char    *s_start;               /* start of the current string */
 extern char    *l_acmbeg;              /* string introducing a comment */
 extern char    *l_acmend;              /* string ending a comment */
-extern char    *l_blkbeg;              /* string begining of a block */
+extern char    *l_blkbeg;              /* string beginning of a block */
 extern char    *l_blkend;              /* string ending a block */
 extern char    *l_chrbeg;              /* delimiter for character constant */
 extern char    *l_chrend;              /* delimiter for character constant */

Modified: head/usr.bin/vgrind/vfontedpr.c
==============================================================================
--- head/usr.bin/vgrind/vfontedpr.c     Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/vgrind/vfontedpr.c     Fri Dec 30 11:02:40 2011        
(r228992)
@@ -110,7 +110,7 @@ static char pstack[PSMAX][PNAMELEN+1];      /
 
 char   *l_acmbeg;              /* string introducing a comment */
 char   *l_acmend;              /* string ending a comment */
-char   *l_blkbeg;              /* string begining of a block */
+char   *l_blkbeg;              /* string beginning of a block */
 char   *l_blkend;              /* string ending a block */
 char    *l_chrbeg;             /* delimiter for character constant */
 char    *l_chrend;             /* delimiter for character constant */

Modified: head/usr.bin/xlint/lint1/decl.c
==============================================================================
--- head/usr.bin/xlint/lint1/decl.c     Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/lint1/decl.c     Fri Dec 30 11:02:40 2011        
(r228992)
@@ -308,7 +308,7 @@ addtype(type_t *tp)
 
        /* now it can be only a combination of arithmetic types and void */
        if (t == SIGNED || t == UNSIGN) {
-               /* remeber specifiers "signed" and "unsigned" in dcs->d_smod */
+               /* remember specifiers "signed" and "unsigned" in dcs->d_smod */
                if (dcs->d_smod != NOTSPEC)
                        /*
                         * more than one "signed" and/or "unsigned"; print
@@ -545,7 +545,7 @@ popdecl(void)
                /*
                 * casts and sizeof
                 * Append all symbols declared in the abstract declaration
-                * to the list of symbols declared in the surounding decl.
+                * to the list of symbols declared in the surrounding decl.
                 * or block.
                 * XXX I'm not sure whether they should be removed from the
                 * symbol table now or later.
@@ -2580,8 +2580,8 @@ ledecl(sym_t *dsym)
 }
 
 /*
- * Print an error or a warning if the symbol cant be initialized due
- * to type/storage class. Returnvalue is 1 if an error has been
+ * Print an error or a warning if the symbol can't be initialized due
+ * to type/storage class. Return value is 1 if an error has been
  * detected.
  */
 static int
@@ -2613,7 +2613,7 @@ chkinit(sym_t *sym)
 }
 
 /*
- * Create a symbole for an abstract declaration.
+ * Create a symbol for an abstract declaration.
  */
 sym_t *
 aname(void)
@@ -2895,7 +2895,7 @@ chktusg(sym_t *sym)
        if (!incompl(sym->s_type))
                return;
 
-       /* complain alwasy about incomplet tags declared inside blocks */
+       /* complain always about incomplete tags declared inside blocks */
        if (!zflag || dcs->d_ctx != EXTERN)
                return;
 

Modified: head/usr.bin/xlint/lint1/emit1.c
==============================================================================
--- head/usr.bin/xlint/lint1/emit1.c    Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/lint1/emit1.c    Fri Dec 30 11:02:40 2011        
(r228992)
@@ -81,7 +81,7 @@ static        void    outfstrg(strg_t *);
  *                             2 n typename            only type name
  *
  * spaces are only for better readability
- * additionaly it is possible to prepend the characters 'c' (for const)
+ * additionally it is possible to prepend the characters 'c' (for const)
  * and 'v' (for volatile)
  */
 void

Modified: head/usr.bin/xlint/lint1/func.c
==============================================================================
--- head/usr.bin/xlint/lint1/func.c     Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/lint1/func.c     Fri Dec 30 11:02:40 2011        
(r228992)
@@ -59,15 +59,15 @@ int reached = 1;
 int    rchflg;
 
 /*
- * In conjunction with reached ontrols printing of "fallthrough on ..."
+ * In conjunction with reached controls printing of "fallthrough on ..."
  * warnings.
  * Reset by each statement and set by FALLTHROUGH, switch (switch1())
  * and case (label()).
  *
  * Control statements if, for, while and switch do not reset ftflg because
- * this must be done by the controled statement. At least for if this is
+ * this must be done by the controlled statement. At least for if this is
  * important because ** FALLTHROUGH ** after "if (expr) stmnt" is evaluated
- * befor the following token, wich causes reduction of above, is read.
+ * before the following token, which causes reduction of above, is read.
  * This means that ** FALLTHROUGH ** after "if ..." would always be ignored.
  */
 int    ftflg;
@@ -107,13 +107,13 @@ pos_t     prflpos;
 pos_t  scflpos;
 
 /*
- * Are both plibflg and llibflg set, prototypes are writen as function
+ * Are both plibflg and llibflg set, prototypes are written as function
  * definitions to the output file.
  */
 int    plibflg;
 
 /*
- * Nonzero means that no warnings about constands in conditional
+ * Nonzero means that no warnings about constants in conditional
  * context are printed.
  */
 int    ccflg;
@@ -323,7 +323,7 @@ funcdef(sym_t *fsym)
 
        if (fsym->s_osdef && !fsym->s_type->t_proto) {
                if (sflag && hflag && strcmp(fsym->s_name, "main") != 0)
-                       /* function definition is not a prototyp */
+                       /* function definition is not a prototype */
                        warning(286);
        }
 
@@ -353,7 +353,7 @@ funcend(void)
        }
 
        /*
-        * This warning is printed only if the return value was implizitly
+        * This warning is printed only if the return value was implicitly
         * declared to be int. Otherwise the wrong return statement
         * has already printed a warning.
         */

Modified: head/usr.bin/xlint/lint1/mem1.c
==============================================================================
--- head/usr.bin/xlint/lint1/mem1.c     Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/lint1/mem1.c     Fri Dec 30 11:02:40 2011        
(r228992)
@@ -133,7 +133,7 @@ getfnid(const char *s)
 /*
  * Memory for declarations and other things which must be available
  * until the end of a block (or the end of the translation unit)
- * are assoziated with the level (mblklev) of the block (or wiht 0).
+ * are associated with the level (mblklev) of the block (or with 0).
  * Because these memory is allocated in large blocks associated with
  * a given level it can be freed easily at the end of a block.
  */

Modified: head/usr.bin/xlint/lint2/chk.c
==============================================================================
--- head/usr.bin/xlint/lint2/chk.c      Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/lint2/chk.c      Fri Dec 30 11:02:40 2011        
(r228992)
@@ -447,11 +447,11 @@ chkau(hte_t *hte, int n, sym_t *def, sym
        char    *pos1;
 
        /*
-        * If a function definition is available (def != NULL), we compair the
+        * If a function definition is available (def != NULL), we compare the
         * function call (call) with the definition. Otherwise, if a function
         * definition is available and it is not an old style definition
-        * (decl != NULL && TP(decl->s_type)->t_proto), we compair the call
-        * with this declaration. Otherwise we compair it with the first
+        * (decl != NULL && TP(decl->s_type)->t_proto), we compare the call
+        * with this declaration. Otherwise we compare it with the first
         * call we have found (call1).
         */
 
@@ -474,7 +474,7 @@ chkau(hte_t *hte, int n, sym_t *def, sym
         * of an argument does not match exactly the expected type. The
         * result are lots of warnings which are really not necessary.
         * We print a warning only if
-        *   (0) at least one type is not an interger type and types differ
+        *   (0) at least one type is not an integer type and types differ
         *   (1) hflag is set and types differ
         *   (2) types differ, except in signedness
         * If the argument is an integer constant whose msb is not set,
@@ -482,7 +482,7 @@ chkau(hte_t *hte, int n, sym_t *def, sym
         * int). This is with and without hflag.
         * If the argument is an integer constant with value 0 and the
         * expected argument is of type pointer and the width of the
-        * interger constant is the same as the width of the pointer,
+        * integer constant is the same as the width of the pointer,
         * no warning is printed.
         */
        t1 = arg1->t_tspec;
@@ -490,7 +490,7 @@ chkau(hte_t *hte, int n, sym_t *def, sym
        if (isityp(t1) && isityp(t2) && !arg1->t_isenum && !arg2->t_isenum) {
                if (promote) {
                        /*
-                        * XXX Here is a problem: Althrough it is possible to
+                        * XXX Here is a problem: Although it is possible to
                         * pass an int where a char/short it expected, there
                         * may be loss in significant digits. We should first
                         * check for const arguments if they can be converted

Modified: head/usr.bin/xlint/lint2/read.c
==============================================================================
--- head/usr.bin/xlint/lint2/read.c     Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/lint2/read.c     Fri Dec 30 11:02:40 2011        
(r228992)
@@ -506,7 +506,7 @@ decldef(pos_t *posp, const char *cp)
 }
 
 /*
- * Read an u-record (emited by lint1 if a symbol was used).
+ * Read an u-record (emitted by lint1 if a symbol was used).
  */
 static void
 usedsym(pos_t *posp, const char *cp)

Modified: head/usr.bin/xlint/xlint/xlint.c
==============================================================================
--- head/usr.bin/xlint/xlint/xlint.c    Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/xlint/xlint/xlint.c    Fri Dec 30 11:02:40 2011        
(r228992)
@@ -80,7 +80,7 @@ static        char    *p2out;
 /* flags always passed to cc(1) */
 static char    **cflags;
 
-/* flags for cc(1), controled by sflag/tflag */
+/* flags for cc(1), controlled by sflag/tflag */
 static char    **lcflags;
 
 /* flags for lint1 */

Modified: head/usr.bin/yacc/NEW_FEATURES
==============================================================================
--- head/usr.bin/yacc/NEW_FEATURES      Fri Dec 30 10:59:15 2011        
(r228991)
+++ head/usr.bin/yacc/NEW_FEATURES      Fri Dec 30 11:02:40 2011        
(r228992)
@@ -1,3 +1,5 @@
+$FreeBSD$
+
      The -r option has been implemented.  The -r option tells Yacc to
 put the read-only tables in y.tab.c and the code and variables in
 y.code.c.  Keith Bostic asked for this option so that :yyfix could be
@@ -35,7 +37,7 @@ is
 
          %ident string
 
-where string is a sequence of characters begining with a double quote
+where string is a sequence of characters beginning with a double quote
 and ending with either a double quote or the next end-of-line, whichever
 comes first.  The declaration will cause a #ident directive to be written
 near the start of the output file.

Modified: head/usr.bin/yacc/reader.c
==============================================================================